@@ -34,6 +34,9 @@ QDltFile::QDltFile()
     filterFlag = false;
     sortByTimeFlag = false;
     sortByTimestampFlag = false;
+
+    cache.setMaxCost(1000);
+    cacheEnable = true;
 }
 
 QDltFile::~QDltFile()
@@ -41,6 +44,30 @@ QDltFile::~QDltFile()
     clear();
 }
 
+void QDltFile::setCacheSize(qsizetype cost)
+{
+    if(cost==0)
+    {
+        cacheEnable = false;
+        cache.setMaxCost(1);
+    }
+    else
+    {
+        cacheEnable = true;
+        cache.setMaxCost(cost);
+    }
+}
+
+void QDltFile::setDLTv2Support(bool _dltv2Support)
+{
+    dltv2Support = _dltv2Support;
+}
+
+bool QDltFile::getDLTv2Support() const
+{
+    return dltv2Support;
+}
+
 void QDltFile::clear()
 {
     for(int num=0;num<files.size();num++)
@@ -51,6 +78,8 @@ void QDltFile::clear()
         delete(files[num]);
     }
     files.clear();
+
+    cache.clear();
 }
 
 int QDltFile::getNumberOfFiles() const
@@ -103,7 +132,7 @@ int QDltFile::sizeFilter() const
 
 bool QDltFile::open(QString _filename, bool append)
 {
-    qDebug() << "Open file" << _filename << "started" << __FILE__ << __LINE__;
+    qDebug() << "Open file" << _filename << "started";
 
     /* check if file is already opened */
     if(!append)
@@ -412,7 +441,7 @@ bool QDltFile::updateIndexFilter()
     for(int num=index;num<size();num++) {
         buf = getMsg(num);
         if(!buf.isEmpty()) {
-            msg.setMsg(buf);
+            msg.setMsg(buf,true,dltv2Support);
             msg.setIndex(num);
             if(checkFilter(msg)) {
                 indexFilter.append(num);
@@ -473,7 +502,7 @@ void QDltFile::addFilterIndex (int index)
  {
      if(!filterFlag)
      {
-         return QString(DEFAULT_COLOR);
+         return QString(""); // invalid colour
      }
 
      return filterList.checkMarker(msg);
@@ -585,17 +614,47 @@ QByteArray QDltFile::getMsg(int index) const
     return buf;
 }
 
-bool QDltFile::getMsg(int index,QDltMsg &msg) const
+bool QDltFile::getMsg(int index,QDltMsg &msg)
 {
-    QByteArray data = getMsg(index);
+    bool result;
+    QDltMsg *cacheMsg;
 
+    // check if msg is already in cache
+    if(cacheEnable)
+    {
+        mutexQDlt.lock();
+        cacheMsg = cache[index];
+        if(cacheMsg)
+        {
+            // load from cache
+            msg = *cacheMsg;
+            mutexQDlt.unlock();
+            return true;
+        }
+        mutexQDlt.unlock();
+    }
+
+    // load message from DLT file
+    QByteArray data = getMsg(index);
     if(data.isEmpty())
         return false;
-
-    bool result = msg.setMsg(data);
-
+    result = msg.setMsg(data,true,dltv2Support);
     msg.setIndex(index);
 
+    // store msg in cache
+    if(cacheEnable && result)
+    {
+        cacheMsg = new QDltMsg();
+        *cacheMsg = msg;
+        mutexQDlt.lock();
+        if(!cache.insert(index,cacheMsg))
+        {
+            // object deleted already by insert function
+            // delete cacheMsg;
+        }
+        mutexQDlt.unlock();
+    }
+
     return result;
 }
 
