@@ -151,14 +151,10 @@ QString QDltMsg::getGmTimeWithOffsetString(qlonglong offset, bool dst)
     return gmDateTime.toString("yyyy/MM/dd hh:mm:ss");
 }
 
-quint32 QDltMsg::checkMsgSize(const char *data,quint32 size)
+quint32 QDltMsg::checkMsgSize(const char *data,quint32 size,bool supportDLTv2)
 {
     int sizeStorageHeader = 0;
-    quint32 storageHeaderTimestampNanoseconds = 0;
-    quint64 storageHeaderTimestampSeconds = 0;
     QString storageHeaderEcuId;
-    bool withStorageHeader=false;
-    const DltStorageHeader *storageheader = 0;
 
     /* empty message */
     clear();
@@ -171,22 +167,15 @@ quint32 QDltMsg::checkMsgSize(const char *data,quint32 size)
     }
     if(data[0]=='D' && data[1]=='L' && data[2]=='T')
     {
-        withStorageHeader = true;
         quint8 storageHeaderVersion = *((quint8*) (data + 3));
         if(storageHeaderVersion==1)
         {
             sizeStorageHeader = sizeof(DltStorageHeader);
-            if(size < (int)(sizeStorageHeader))
+            if(size < (quint32)(sizeStorageHeader))
             {
                 // length error
                 return 0;
             }
-
-            if(withStorageHeader)
-            {
-                storageheader = (DltStorageHeader*) data;
-            }
-
         }
         else if(storageHeaderVersion==2)
         {
@@ -195,14 +184,8 @@ quint32 QDltMsg::checkMsgSize(const char *data,quint32 size)
                 // length error
                 return 0;
             }
-            storageHeaderTimestampNanoseconds = *((quint32*) (data + 4)); // not in big endian format
-            storageHeaderTimestampSeconds = (((quint64)(*((quint8*) (data + 12))))<<32)|
-                               (((quint64)(*((quint8*) (data + 11))))<<24)|
-                               (((quint64)(*((quint8*) (data + 10))))<<16)|
-                               (((quint64)(*((quint8*) (data + 9))))<<8)|
-                               (((quint64)(*((quint8*) (data + 8)))));
             quint8 ecuIdLength = *((quint8*) (data + 13));
-            if(size < (int)(14+ecuIdLength)) {
+            if(size < (quint32)(14+ecuIdLength)) {
                 return 0; // length error
             }
             storageHeaderEcuId = QString(QByteArray(data+14,ecuIdLength));
@@ -216,17 +199,17 @@ quint32 QDltMsg::checkMsgSize(const char *data,quint32 size)
     }
 
     /* get DLT protocol version */
-    if(size < (int)(sizeStorageHeader+4)) {
+    if(size < (quint32)(sizeStorageHeader+4)) {
         return 0;
     }
     quint32 htyp2 = *((quint32*) (data + sizeStorageHeader));
     versionNumber = (htyp2 & 0xe0) >> 5;  // Byte 0, Bit 5-7
 
 
-    if(versionNumber==1)
+    if(!supportDLTv2 || versionNumber==1)
     {
         const DltStandardHeader *standardheader = 0;
-        unsigned int extra_size,headersize,datasize;
+        unsigned int extra_size,headersize;
 
         if(size < (int)(sizeStorageHeader+sizeof(DltStandardHeader))) {
             return 0;
@@ -245,7 +228,7 @@ quint32 QDltMsg::checkMsgSize(const char *data,quint32 size)
         }
         else
         {
-            if(size < (DLT_SWAP_16(standardheader->len) + sizeStorageHeader))
+            if(size < (quint32)(DLT_SWAP_16(standardheader->len) + sizeStorageHeader))
             {
                 // whole message does not fit
                 return 0;
@@ -302,7 +285,7 @@ quint32 QDltMsg::checkMsgSize(const char *data,quint32 size)
         /* get Message Length */
         quint16 messageLength = messageLength = qFromBigEndian(*((quint16*) (data + 5 + sizeStorageHeader)));
 
-        if(size < (messageLength+sizeStorageHeader))
+        if(size < (quint32)(messageLength+sizeStorageHeader))
         {
             // whole message does not fit
             return 0;
@@ -316,7 +299,7 @@ quint32 QDltMsg::checkMsgSize(const char *data,quint32 size)
     }
 }
 
-bool QDltMsg::setMsg(const QByteArray& buf, bool withStorageHeader)
+bool QDltMsg::setMsg(const QByteArray& buf, bool withStorageHeader,bool supportDLTv2)
 {
     unsigned int offset;
     QDltArgument argument;
@@ -375,7 +358,7 @@ bool QDltMsg::setMsg(const QByteArray& buf, bool withStorageHeader)
     quint32 htyp2 = *((quint32*) (buf.constData() + sizeStorageHeader));
     versionNumber = (htyp2 & 0xe0) >> 5;  // Byte 0, Bit 5-7
 
-    if(versionNumber==1)
+    if(!supportDLTv2 || versionNumber==1)
     {
 
         if(buf.size() < (int)(sizeStorageHeader+sizeof(DltStandardHeader))) {
