@@ -33,7 +33,12 @@ enum e_convertionmode
     e_DDLT = 4,
 };
 
-
+enum class e_inputmode
+{
+    DLT    = 0,
+    STREAM = 1,
+    SERIAL = 2,
+};
 
 class QDLT_EXPORT QDltOptManager
 {
@@ -44,24 +49,28 @@ public:
     void parse(QStringList *opt);
 
     bool isProjectFile();
-    bool isLogFile();
-    bool isFilterFile();
-    bool isConvert();
+    bool isTerminate();
     bool isConvertUTF8();
-    bool isPlugin();
     bool issilentMode();
     bool isCommandlineMode();
 
     e_convertionmode get_convertionmode();
+    e_inputmode get_inputmode();
 
     QString getProjectFile();
-    QString getLogFile();
-    QString getFilterFile();
-    QString getConvertSourceFile();
+    QStringList getLogFiles();
+    QStringList getFilterFiles();
     QString getConvertDestFile();
     QString getPluginName();
     QString getCommandName();
     QStringList getCommandParams();
+    QString getWorkingDirectory() const;
+    const QStringList &getPrePluginCommands() const;
+    const QStringList &getPostPluginCommands() const;
+
+    const QStringList &getPcapFiles() const;
+
+    const QStringList &getMf4Files() const;
 
 private:
     QDltOptManager();
@@ -69,22 +78,26 @@ private:
     static QDltOptManager *instance;
 
     bool project;
-    bool log;
-    bool filter;
-    bool convert;
-    bool plugin;
+    bool terminate;
     bool silent_mode;
     bool commandline_mode;
     e_convertionmode convertionmode;
+    e_inputmode inputmode{e_inputmode::DLT};
 
     QString projectFile;
-    QString logFile;
-    QString filterFile;
-    QString convertSourceFile;
+    QStringList logFiles;
+    QStringList pcapFiles;
+    QStringList mf4Files;
+    QStringList filterFiles;
     QString convertDestFile;
     QString pluginName;
     QString commandName;
     QStringList commandParams;
+
+    QStringList prePluginCommands; // command before loading log file
+    QStringList postPluginCommands; // command after loading log file
+
+    QString  workingDirectory;
 };
 
 #endif //QDLTOPTMANAGER_H
