@@ -1,7 +1,6 @@
 #include "qdltplugin.h"
 #include "qdltpluginmanager.h"
 
-
 #include <QDir>
 #include <QDebug>
 #include <QCoreApplication>
@@ -17,7 +16,7 @@
 
 QDltPluginManager::QDltPluginManager()
 {
-    pMutex_pluginList = new QMutex(QMutex::Recursive);
+    pMutex_pluginList = new QMutex();
 }
 
 QDltPluginManager::~QDltPluginManager()
@@ -155,7 +154,7 @@ void QDltPluginManager::loadConfig(QString pluginName,QString filename)
     for(int num=0;num<plugins.size();num++)
     {
         QDltPlugin *plugin = plugins[num];
-        if(plugin->getName()==pluginName)
+        if(plugin->name()==pluginName)
             plugin->setFilename(filename);
     }
     pMutex_pluginList->unlock();
@@ -182,14 +181,16 @@ QDltPlugin* QDltPluginManager::findPlugin(QString &name)
     pMutex_pluginList->lock();
     for(int num=0;num<plugins.size();num++)
     {
-        if(plugins[num]->getName()==name)
+        QDltPlugin *plugin = plugins[num];
+
+        if(plugin->name()==name)
         {
-            plugin = plugins[num];
-            break;
+            pMutex_pluginList->unlock();
+            return plugin;
         }
     }
-    pMutex_pluginList->unlock();
 
+    pMutex_pluginList->unlock();
     return plugin;
 }
 
@@ -217,7 +218,7 @@ bool QDltPluginManager::decreasePluginPriority(const QString &name)
         pMutex_pluginList->lock();
         for(int num=0; num < plugins.size()-1; ++num)
         {
-            if(plugins[num]->getName() == name)
+            if(plugins[num]->name() == name)
             {
                 qDebug() << "decrease prio of" << name << "from" << num << "to" << num+1;
                 plugins.move(num, num+1);
@@ -240,7 +241,7 @@ bool QDltPluginManager::raisePluginPriority(const QString &name)
         pMutex_pluginList->lock();
         for(int num=1; num < plugins.size(); ++num)
         {
-            if( plugins[num]->getName() == name)
+            if( plugins[num]->name() == name)
             {
                 qDebug() << "raise prio of" << name << "from" << num << "to" << num-1;
                 plugins.move(num, num-1);
@@ -259,16 +260,16 @@ bool QDltPluginManager::setPluginPriority(const QString name, unsigned int prio)
     bool result = false;
 
     //if prio is too large, put to the end of the list
-    if(prio >= plugins.size()) {
+    if(prio >= (unsigned int) (plugins.size())) {
         prio = plugins.size() - 1;
     }
 
     if(plugins.size() > 1) {
         pMutex_pluginList->lock();
         for (int num = 0; num < plugins.size(); ++num) {
-            if (plugins[num]->getName() == name) {
+            if (plugins[num]->name() == name) {
                 if (prio != num) {
-                    qDebug() << "changing prio of" << name << "from" << num << "to" << prio;
+                    qDebug() << "Changing priority of plugin" << name << "from" << num << "to" << prio;
                     plugins.move(num, prio);
                 }
                 result = true;
@@ -289,7 +290,7 @@ QStringList QDltPluginManager::getPluginPriorities() const
         pMutex_pluginList->lock();
         for(int num=0; num < plugins.size(); ++num)
         {
-            finalPrio << plugins[num]->getName();
+            finalPrio << plugins[num]->name();
         }
         pMutex_pluginList->unlock();
     }
