@@ -9,7 +9,7 @@
 #include "fieldnames.h"
 #include "qdltoptmanager.h"
 
-DltExporter::DltExporter(QObject *parent) :
+DltExporter::DltExporter(Project *_project,QObject *parent) :
     QObject(parent)
 {
     size = 0;
@@ -21,6 +21,7 @@ DltExporter::DltExporter(QObject *parent) :
     exportSelection = SelectionAll;
     starting_index=0;
     stoping_index=0;
+    project = _project;
 }
 
 QString DltExporter::escapeCSVValue(QString arg)
@@ -54,18 +55,21 @@ void DltExporter::writeCSVLine(int index, QFile *to, QDltMsg msg)
     QString text("");
 
     text += escapeCSVValue(QString("%1").arg(index)).append(",");
-    text += escapeCSVValue(QString("%1.%2").arg(msg.getTimeString()).arg(msg.getMicroseconds(),6,10,QLatin1Char('0'))).append(",");
+    if( project->settings->automaticTimeSettings == 0 )
+       text += escapeCSVValue(QString("%1.%2").arg(msg.getGmTimeWithOffsetString(project->settings->utcOffset,project->settings->dst)).arg(msg.getMicroseconds(),6,10,QLatin1Char('0'))).append(",");
+    else
+       text += escapeCSVValue(QString("%1.%2").arg(msg.getTimeString()).arg(msg.getMicroseconds(),6,10,QLatin1Char('0'))).append(",");
     text += escapeCSVValue(QString("%1.%2").arg(msg.getTimestamp()/10000).arg(msg.getTimestamp()%10000,4,10,QLatin1Char('0'))).append(",");
     text += escapeCSVValue(QString("%1").arg(msg.getMessageCounter())).append(",");
-    text += escapeCSVValue(QString("%1").arg(msg.getEcuid())).append(",");
-    text += escapeCSVValue(QString("%1").arg(msg.getApid())).append(",");
-    text += escapeCSVValue(QString("%1").arg(msg.getCtid())).append(",");
+    text += escapeCSVValue(QString("%1").arg(msg.getEcuid().simplified())).append(",");
+    text += escapeCSVValue(QString("%1").arg(msg.getApid().simplified())).append(",");
+    text += escapeCSVValue(QString("%1").arg(msg.getCtid().simplified())).append(",");
     text += escapeCSVValue(QString("%1").arg(msg.getSessionid())).append(",");
     text += escapeCSVValue(QString("%1").arg(msg.getTypeString())).append(",");
     text += escapeCSVValue(QString("%1").arg(msg.getSubtypeString())).append(",");
     text += escapeCSVValue(QString("%1").arg(msg.getModeString())).append(",");
     text += escapeCSVValue(QString("%1").arg(msg.getNumberOfArguments())).append(",");
-    text += escapeCSVValue(msg.toStringPayload().simplified());
+    text += escapeCSVValue(msg.toStringPayload().simplified().remove(QChar::Null));
     text += "\n";
 
     to->write(text.toLatin1().constData());
@@ -184,7 +188,9 @@ bool DltExporter::finish()
         {
             clipboardString.resize(clipboardString.size() - 1);
         }
-        clipboard->setText(clipboardString);
+        /* remove null characters */
+        clipboardString.remove(QChar::Null);
+        clipboard->setText(clipboardString,QClipboard::Clipboard);
     }
 
     return true;
@@ -260,10 +266,24 @@ bool DltExporter::exportMsg(unsigned long int num, QDltMsg &msg, QByteArray &buf
                 text += QString("%1 ").arg(from->getMsgFilterPos(selectedRows[num]));
             else
                 return false;
-            text += msg.toStringHeader();
+            if( project->settings->automaticTimeSettings == 0 )
+               text += QString("%1.%2").arg(msg.getGmTimeWithOffsetString(project->settings->utcOffset,project->settings->dst)).arg(msg.getMicroseconds(),6,10,QLatin1Char('0'));
+            else
+               text += QString("%1.%2").arg(msg.getTimeString()).arg(msg.getMicroseconds(),6,10,QLatin1Char('0'));
+            text += QString(" %1.%2").arg(msg.getTimestamp()/10000).arg(msg.getTimestamp()%10000,4,10,QLatin1Char('0'));
+            text += QString(" %1").arg(msg.getMessageCounter());
+            text += QString(" %1").arg(msg.getEcuid());
+            text += QString(" %1").arg(msg.getApid());
+            text += QString(" %1").arg(msg.getCtid());
+            text += QString(" %1").arg(msg.getSessionid());
+            text += QString(" %2").arg(msg.getTypeString());
+            text += QString(" %2").arg(msg.getSubtypeString());
+            text += QString(" %2").arg(msg.getModeString());
+            text += QString(" %1").arg(msg.getNumberOfArguments());
+
             text += " ";
         }
-        text += msg.toStringPayload().trimmed();
+        text += msg.toStringPayload().simplified().remove(QChar::Null);
         text += "\n";
         try
          {
@@ -305,12 +325,15 @@ bool DltExporter::exportMsg(unsigned long int num, QDltMsg &msg, QByteArray &buf
         else
             return false;
 
-        text += "|" + QString("%1.%2").arg(msg.getTimeString()).arg(msg.getMicroseconds(),4,10,QLatin1Char('0')) +
-                "|" + QString("%1.%2").arg(msg.getTimestamp()/10000).arg(msg.getTimestamp()%10000,4,10,QLatin1Char('0')) +
+        if( project->settings->automaticTimeSettings == 0 )
+           text += "|" + QString("%1.%2").arg(msg.getGmTimeWithOffsetString(project->settings->utcOffset,project->settings->dst)).arg(msg.getMicroseconds(),6,10,QLatin1Char('0'));
+        else
+           text += "|" + QString("%1.%2").arg(msg.getTimeString()).arg(msg.getMicroseconds(),6,10,QLatin1Char('0'));
+        text += "|" + QString("%1.%2").arg(msg.getTimestamp()/10000).arg(msg.getTimestamp()%10000,4,10,QLatin1Char('0')) +
                 "|" + msg.getEcuid() +
                 "|" + msg.getApid() +
                 "|" + msg.getCtid() +
-                "|" + msg.toStringPayload().trimmed().replace('|', "\\|").replace('#', "\\#").replace('*', "\\*") +
+                "|" + msg.toStringPayload().simplified().remove(QChar::Null).replace('|', "\\|").replace('#', "\\#").replace('*', "\\*") +
                 "| |\n";
         clipboardString += text;
     }
@@ -380,7 +403,7 @@ void DltExporter::exportMessages(QDltFile *from, QFile *to, QDltPluginManager *p
       fileprogress.show();
      }
 
-    for(starting;starting<stoping;starting++)
+    for(;starting<stoping;starting++)
     {
         // Update progress dialog every 1000 lines
 
