@@ -28,11 +28,22 @@
 int main(int argc, char *argv[])
 {
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
+#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0) && QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
 #endif
 
+    // check if silent mode or help is requested
+    // if yes, activate offscreen mode to be able to run also without display
+    for(int i=0;i<argc;i++)
+    {
+        if(strcmp(argv[i],"-s")==0 || strcmp(argv[i],"--silent")==0 || strcmp(argv[i],"-h")==0 || strcmp(argv[i],"--help")==0)
+        {
+            qputenv("QT_QPA_PLATFORM","offscreen");
+            break;
+        }
+    }
+
     QApplication a(argc, argv);
 
     QStringList arguments = a.arguments();
@@ -40,16 +51,6 @@ int main(int argc, char *argv[])
     opt->parse(&arguments);
 
     MainWindow w;
-    /* check variable commandline_finished
-       instead of stopping during constructor run
-       after running a commandline mode call
-       which often leads to crash
-    */
-    if(opt->getInstance()->isConvert() == true )
-    {
-        return 0;
-    }
-
     w.show();
 
     return a.exec();
