@@ -31,9 +31,7 @@
 #include <QCompleter>
 #include <QStringListModel>
 
-#include "qdlt.h"
 #include "tablemodel.h"
-#include "project.h"
 #include "settingsdialog.h"
 #include "searchdialog.h"
 #include "filterdialog.h"
@@ -179,7 +177,7 @@ private:
     QStringList autoloadPluginsVersionStrings;
 
     /* String List Containing Search History */
-    enum { MaxSearchHistory = 20 };
+    enum { MaxSearchHistory = 50 };
     QAction *searchHistoryActs[MaxSearchHistory];
     QStringList searchHistory;
 
@@ -213,8 +211,6 @@ private:
     quint16 senderPort; // in readdatagramm
 
     /* used in ::read() */
-    QByteArray bufferHeader;
-    QByteArray bufferPayload;
     QByteArray data;
     QDltMsg qmsg;
 
@@ -383,6 +379,8 @@ private:
     /* Get path from explorerView model index */
     QString getPathFromExplorerViewIndexModel(const QModelIndex &proxyIndex);
 
+    void writeDLTMessageToFile(QByteArray &bufferHeader,char*bufferPayload,quint32 bufferPayloadSize,EcuItem* ecuitem,quint32 sec=0,quint32 use=0);
+
 protected:
     void keyPressEvent ( QKeyEvent * event );
     void dragEnterEvent(QDragEnterEvent *event);
@@ -417,7 +415,7 @@ private slots:
 
     void on_pluginWidget_itemExpanded(QTreeWidgetItem* item);
 
-    void on_pluginWidget_pluginPriorityChanged(const QString name, int prio);
+    void onPluginWidgetPluginPriorityChanged(const QString name, int prio);
 
 // File methods
 
@@ -426,10 +424,10 @@ private slots:
     void on_action_menuFile_New_triggered();
     void on_action_menuFile_SaveAs_triggered();
     void on_action_menuFile_Import_DLT_Stream_with_Serial_Header_triggered();
-    void on_action_menuFile_Append_DLT_File_triggered();
     void on_action_menuFile_Import_DLT_Stream_triggered();
     void on_action_menuFile_Settings_triggered();
     void on_action_menuFile_Open_triggered();
+    void on_actionAppend_triggered();
     void on_actionExport_triggered();
 
     void on_pushButtonMovePluginUp_clicked();
@@ -491,7 +489,7 @@ private slots:
     void onActionMenuConfigSearchTableCopyJiraToClipboardTriggered();
     void onActionMenuConfigSearchTableCopyJiraHeadToClipboardTriggered();
 
-    void on_action_menuConfig_Save_All_ECUs_triggered();
+    void onActionMenuConfigSaveAllECUsTriggered();
 
     // DLT methods
     void on_action_menuDLT_Send_Injection_triggered();
@@ -558,8 +556,6 @@ private slots:
     void on_applyConfig_clicked();
     void on_tabWidget_currentChanged(int index);
 
-    void on_comboBoxFilterSelection_activated(const QString &arg1);
-
     void on_actionDefault_Filter_Reload_triggered();
 
     void on_actionDefault_Filter_Create_Index_triggered();
@@ -589,6 +585,8 @@ private slots:
 
     void on_lineEditFilterEnd_textChanged(const QString &arg1);
 
+    void on_comboBoxFilterSelection_currentTextChanged(const QString &arg1);
+
 public slots:
 
     void sendInjection(int index,QString applicationId,QString contextId,int serviceId,QByteArray data);
