@@ -20,6 +20,7 @@
 #include "searchdialog.h"
 #include "ui_searchdialog.h"
 #include "mainwindow.h"
+#include "qdltoptmanager.h"
 
 #include <QMessageBox>
 #include <QProgressBar>
@@ -289,16 +290,10 @@ int SearchDialog::find()
             return 1;
         }
 
-        searchTextRegExpression.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
-        if ( getCaseSensitive() == true )
-        {
-         searchTextRegExpression.setPatternOptions(QRegularExpression::NoPatternOption);
-        }
-        else
-        {
-         searchTextRegExpression.setPatternOptions(QRegularExpression::CaseInsensitiveOption);
-        }
-
+        int options = QRegularExpression::DotMatchesEverythingOption;
+        if (!getCaseSensitive())
+            options |= QRegularExpression::CaseInsensitiveOption;
+        searchTextRegExpression.setPatternOptions(static_cast<QRegularExpression::PatternOption>(options));
     }
 
     //check timestamp search pattern
@@ -460,6 +455,7 @@ void SearchDialog::findMessages(long int searchLine, long int searchBorder, QReg
         /* get the message with the selected item id */
         buf = file->getMsgFilter(searchLine);
         msg.setMsg(buf);
+        msg.setIndex(file->getMsgFilterPos(searchLine));
 
         /* decode the message if desired - could this call be avoided as the message is already decoded elsewhere ? */
         if(QDltSettingsManager::getInstance()->value("startup/pluginsEnabled", true).toBool())
@@ -476,7 +472,7 @@ void SearchDialog::findMessages(long int searchLine, long int searchBorder, QReg
             text += msg.toStringHeader();
             if ( msgIdEnabled==true )
             {
-                text += " "+QString().sprintf(msgIdFormat.toLatin1(),msg.getMessageId());
+                text += " "+QString::asprintf(msgIdFormat.toUtf8(),msg.getMessageId());
             }
             tempPayLoad = msg.toStringPayload();
 
@@ -674,30 +670,6 @@ bool SearchDialog::payLoadStoppatternCheck()
    return is_PayLoadRangeValid;
 }
 
-
-bool SearchDialog::payLoadValidityCheck()
-{
-    // When the start payload is found, consider range as valid
-    if((tempPayLoad.contains(payloadStart)) && (false == is_PayloadEndFound))
-    {
-        //qDebug() << "Found start payload pattern" << __LINE__;
-        is_PayLoadRangeValid = true;
-        is_PayloadStartFound = true;
-    }
-
-    if(true == is_PayloadStartFound)
-    {
-       if(tempPayLoad.contains(payloadEnd))
-       {
-        //qDebug() << "Found stop payload pattern" << __LINE__;
-        is_PayloadEndFound = true;
-        is_PayLoadRangeValid = false;
-       }
-    }
-
-    return is_PayLoadRangeValid;
-}
-
 bool SearchDialog::timeStampPayloadValidityCheck(long int searchLine)
 {
    // qDebug() << "timeStampPayloadValidityCheck" << __LINE__;
