@@ -22,6 +22,7 @@
 #include "dltuiutils.h"
 #include "dlt_protocol.h"
 #include "regex_search_replace.h"
+#include "qdltoptmanager.h"
 
 
 
@@ -162,7 +163,7 @@ QVariant SearchTableModel::data(const QModelIndex &index, int role) const
             return QString("%1").arg(msg.getNumberOfArguments());
         case FieldNames::Payload:
             /* display payload */
-            visu_data = msg.toStringPayload().trimmed();
+            visu_data = msg.toStringPayload().simplified().remove(QChar::Null);
             if((QDltSettingsManager::getInstance()->value("startup/filtersEnabled", true).toBool()))
             {
                 for(int num = 0; num < project->filter->topLevelItemCount (); num++) {
@@ -174,7 +175,7 @@ QVariant SearchTableModel::data(const QModelIndex &index, int role) const
             }
             return visu_data;
         case FieldNames::MessageId:
-            return QString().sprintf(project->settings->msgIdFormat.toLatin1(),msg.getMessageId());
+            return QString::asprintf(project->settings->msgIdFormat.toUtf8(),msg.getMessageId());
         default:
             if (index.column()>=FieldNames::Arg0)
             {
