@@ -238,11 +238,13 @@ void SettingsDialog::writeDlg()
     ui->lineEditPluginsAutoload->setText(settings->pluginsAutoloadPathName);
     ui->checkBoxFilterCache->setCheckState(settings->filterCache?Qt::Checked:Qt::Unchecked);
     ui->checkBoxAutoConnect->setCheckState(settings->autoConnect?Qt::Checked:Qt::Unchecked);
+    ui->checkBoxSupportDLTV2Decoding->setCheckState(settings->supportDLTv2Decoding?Qt::Checked:Qt::Unchecked);
     ui->checkBoxAutoScroll->setCheckState(settings->autoScroll?Qt::Checked:Qt::Unchecked);
     ui->checkBoxAutoMarkFatalError->setCheckState(settings->autoMarkFatalError?Qt::Checked:Qt::Unchecked);
     ui->checkBoxAutoMarkWarn->setCheckState(settings->autoMarkWarn?Qt::Checked:Qt::Unchecked);
     ui->checkBoxAutoMarkMarker->setCheckState(settings->autoMarkMarker?Qt::Checked:Qt::Unchecked);
     ui->checkBoxLoggingOnlyMode->setCheckState(settings->loggingOnlyMode?Qt::Checked:Qt::Unchecked);
+    ui->checkBoxLoggingOnlyFilteredMessages->setCheckState(settings->loggingOnlyFilteredMessages?Qt::Checked:Qt::Unchecked);
     ui->groupBoxMaxFileSizeMB->setChecked(settings->splitlogfile?Qt::Checked:Qt::Unchecked);
     ui->lineEditMaxFileSizeMB->setText(QString("%1").arg(settings->fmaxFileSizeMB));
     ui->checkBoxAppendDateTime->setCheckState(settings->appendDateTime?Qt::Checked:Qt::Unchecked);
@@ -377,6 +379,7 @@ void SettingsDialog::writeDlg()
     ui->spinBoxFrequency->setValue(settings->RefreshRate);
     ui->checkBoxStartUpMinimized->setChecked(settings->StartupMinimized);
     ui->comboBox_MessageIdFormat->setCurrentText(settings->msgIdFormat);
+    ui->lineEditMsgCacheSize->setText(QString("%1").arg(settings->msgCacheSize));
 
     ui->comboBoxTheme->setCurrentIndex(static_cast<int>(settings->themeSelectionSettings));
 }
@@ -407,11 +410,13 @@ void SettingsDialog::readDlg()
     settings->pluginsAutoloadPathName = ui->lineEditPluginsAutoload->text();
     settings->filterCache = (ui->checkBoxFilterCache->checkState() == Qt::Checked);
     settings->autoConnect = (ui->checkBoxAutoConnect->checkState() == Qt::Checked);
+    settings->supportDLTv2Decoding = (ui->checkBoxSupportDLTV2Decoding->checkState() == Qt::Checked);
     settings->autoScroll = (ui->checkBoxAutoScroll->checkState() == Qt::Checked);
     settings->autoMarkFatalError = (ui->checkBoxAutoMarkFatalError->checkState() == Qt::Checked);
     settings->autoMarkWarn = (ui->checkBoxAutoMarkWarn->checkState() == Qt::Checked);
     settings->autoMarkMarker = (ui->checkBoxAutoMarkMarker->checkState() == Qt::Checked);
     settings->loggingOnlyMode = (ui->checkBoxLoggingOnlyMode->checkState() == Qt::Checked);
+    settings->loggingOnlyFilteredMessages = (ui->checkBoxLoggingOnlyFilteredMessages->checkState() == Qt::Checked);
     settings->splitlogfile = ui->groupBoxMaxFileSizeMB->isChecked();
     if(settings->splitlogfile != 0)
      {
@@ -464,6 +469,7 @@ void SettingsDialog::readDlg()
     settings->RefreshRate = ui->spinBoxFrequency->value();
     settings->StartupMinimized = ui->checkBoxStartUpMinimized->isChecked();
     settings->msgIdFormat=ui->comboBox_MessageIdFormat->currentText();
+    settings->msgCacheSize = ui->lineEditMsgCacheSize->text().toULong();
 
     auto prevUISettings = settings->themeSelectionSettings;
     settings->themeSelectionSettings = static_cast<QDltSettingsManager::UI_Colour>(ui->comboBoxTheme->currentIndex());
@@ -496,7 +502,7 @@ void SettingsDialog::readSettings()
     settings->readSettings();
 
     QPalette palette = ui->labelSelectedMarkerColor->palette();
-    palette.setColor(QPalette::Active,this->backgroundRole(),settings->markercolor);
+    palette.setColor(QPalette::Active,this->backgroundRole(),QColor(settings->markercolorRed,settings->markercolorGreen,settings->markercolorBlue));
     ui->labelSelectedMarkerColor->setPalette(palette);
 
     auto uiColour = settings->themeSelectionSettings;
@@ -702,7 +708,9 @@ void SettingsDialog::on_pushButtonMarkerColor_clicked()
     if(selectedcolor.isValid())
     {
         QDltSettingsManager *settings = QDltSettingsManager::getInstance();
-        settings->markercolor =  selectedcolor;
+        settings->markercolorRed =  selectedcolor.red();
+        settings->markercolorGreen =  selectedcolor.green();
+        settings->markercolorBlue =  selectedcolor.blue();
     }
 }
 
