@@ -248,7 +248,7 @@ TableModel::TableModel(const QString & /*data*/, QObject *parent)
                  return QString("Logging only Mode! Disable in Project Settings!");
              }
              /* display payload */
-             visu_data = msg.toStringPayload().trimmed().replace('\n', ' ');
+             visu_data = msg.toStringPayload().simplified().remove(QChar::Null);
 
              if((QDltSettingsManager::getInstance()->value("startup/filtersEnabled", true).toBool()))
              {
@@ -260,6 +260,12 @@ TableModel::TableModel(const QString & /*data*/, QObject *parent)
                  }
              }
 
+             /* limit size of string to 1000 characters to speed up scrolling */
+             if(visu_data.size()>1000)
+             {
+                visu_data = visu_data.mid(0,1000);
+             }
+
              return visu_data;
          case FieldNames::MessageId:
              return QString::asprintf(project->settings->msgIdFormat.toUtf8() ,msg.getMessageId());
@@ -342,6 +348,30 @@ TableModel::TableModel(const QString & /*data*/, QObject *parent)
         return FieldNames::getColumnAlignment((FieldNames::Fields)index.column(),project->settings);
     }
 
+    if ( role == Qt::ToolTipRole )
+    {
+        getmessage( index.row(), filterposindex, &decodeflag, &msg, &lastmsg, qfile, &success);
+        if ( success == false )
+        {
+            return QString("!!CORRUPTED MESSAGE!!");
+        }
+        if((QDltSettingsManager::getInstance()->value("startup/pluginsEnabled", true).toBool()))
+        {
+            if ( decodeflag == 1 )
+            {
+                decodeflag = 0;
+                last_decoded_msg = msg;
+                pluginManager->decodeMsg(msg,!QDltOptManager::getInstance()->issilentMode());
+                last_decoded_msg = msg;
+            }
+            else
+            {
+                msg = last_decoded_msg;
+            }
+        }
+        return msg.toStringPayload().simplified().remove(QChar::Null);
+    }
+
      return QVariant();
  }
 
